import requests
import logging
from bs4 import BeautifulSoup


def videotags(url):
    try:
        request = requests.get(url)
        soup = BeautifulSoup(request.content, 'html.parser')
        tags = ', '.join([meta.attrs.get("content") for meta in soup.find_all(
            "meta", {"property": "og:video:tag"})])
        return tags
    except Exception as e:
        logging.error(e)
        return False


def channeltags(url):
    try:
        request = requests.get(url)
        soup = BeautifulSoup(request.content, 'html.parser')
        tags = ', '.join([meta.attrs.get("content") for meta in soup.find_all(
            "meta", {"property": "og:video:tag"})])
        return tags
    except Exception as e:
        logging.error(e)
        return False


def videotitle(url):
    try:
        request = requests.get(url)
        soup = BeautifulSoup(request.content, 'html.parser')
        title = soup.find("title").text.strip()
        return title
    except Exception as e:
        logging.error(e)
        return False


def videodescription(url):
    try:
        request = requests.get(url)
        soup = BeautifulSoup(request.content, 'html.parser')
        description = soup.find("meta", {"name": "description"}).attrs.get("content")
        return description
    except Exception as e:
        logging.error(e)
        return False


def channeldescription(url):
    try:
        request = requests.get(url)
        soup = BeautifulSoup(request.content, 'html.parser')
        description = soup.find("meta", {"name": "description"}).attrs.get("content")
        return description
    except Exception as e:
        logging.error(e)
        return False



import pathlib
import setuptools

file = pathlib.Path(__file__).parent

README = (file / "README.md").read_text()

setuptools.setup(
    name="YoutubeTags",
    version="1.4",
    author="Nuhman Pk",
    author_email="nuhmanpk7@gmail.com",
    long_description = README,
    long_description_content_type = "text/markdown",
    description="YoutubeTags is a python third-party api wrapper to Extract Youtube Video Tags without Youtube API",
    license="MIT",
    url="https://github.com/nuhmanpk/YoutubeTags",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(include=['YoutubeTags']),  
    install_requires=[
        'bs4',
        'requests'
    ],
    
    python_requires=">=3.6",
    
)
